import  {
  select, 
  csv, 
  scaleLinear, 
  extent,
  axisLeft, 
  axisBottom,
  format
} from 'd3';
const svg = select("svg");
const width = +svg.attr("width"),
      height = +svg.attr("height");

const render  = data => {
  const xValue = d => d.age;
  const xAxisLabel = "Age";
  const yValue = d => d.hoursPerWeek;
  const yAxisLabel = "Hours Per Week";
  const circleRadius = 8  
  const title = "Census: Age vs. Working Hours";
  const margin = { top: 80, left: 100, bottom: 80, right: 40}
  const innerWidth = width - margin.left - margin.right; 
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice();
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(10);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const g = svg.append("g")
  	.attr("transform", `translate(${margin.left}, ${margin.top})`);
  
  const yAxisG = g.append("g").call(yAxis)
  yAxisG.selectAll(".domain").remove()
  yAxisG.append("text")
  	.attr("class", "axis-label")
  	.attr('x', -innerHeight / 2)
  	.attr('y', -55)
  	.attr('transform', "rotate(-90)")
  	.attr('text-anchor', 'middle')
  	.attr('fill', 'black')
  	.text(yAxisLabel);
  
  const xAxisG = g.append("g").call(xAxis)
  	.attr("transform", `translate(0, ${innerHeight})`);
  
  xAxisG.selectAll(".domain").remove()
  
  xAxisG.append("text")
  	.attr("class", "axis-label")
  	.attr("x", innerWidth / 2)
  	.attr("y", 60)
  	.attr("text-anchor", "middle")
  	.attr("fill", 'black')
  	.text(xAxisLabel);
  
  g.selectAll("circle")
  	.data(data)
  	.enter().append("circle")
  	.attr("cy", d => yScale(yValue(d)))
  	.attr("cx", d => xScale(xValue(d)))
  	.attr("r", circleRadius)
  	.attr("opacity", 0.5)
  	.attr("fill", d => d.sex === "Male" ? "blue" : "pink")
  ;
    
  g.append("text")
  	.attr("y", -20)
  	.attr("x", innerWidth / 2)
  	.attr("text-anchor", "middle")
  	.text(title)	
  const legend = g.append("g")
  	.attr("class", "legend")
  
  legend.append("circle")
  	.attr("r", 8)
  	.attr("cx", 20)
  	.attr("cy", 20)
  	.attr("fill", "pink")
  legend.append("text")
  	.attr("x", 35)
  	.attr("y", 27)
  	.text("Female")
  
  legend.append("circle")
  	.attr("r", 8)
  	.attr("cx", 20)
  	.attr("cy", 50)
  	.attr("fill", "blue")
  legend.append("text")
  	.attr("x", 35)
  	.attr("y", 57)
  	.text("Male")
  	
};

csv("data.csv")
	.then(
  data => {
    data.forEach(d => {
      d.age = +d.age;
      d.fnlwgt = +d.fnlwgt;
      d.educationNum = +d.educationNum;
      d.capitalGain = +d.capitalGain;
      d.capitalLoss = +d.capitalLoss;
      d.hoursPerWeek = +d.hoursPerWeek;
      d.incomeMoreThan50K = d.incomeMoreThan50K === ">50K";
    })
    render(data);
  });